magql
=====

Magql is a `GraphQL`_ framework for Python. It generates a
full-featured, customizable GraphQL API for your data. It's pronounced
"magical", and it is!

.. _GraphQL: https://graphql.org/

.. toctree::
   :maxdepth: 2

   convert
   resolvers
   get_type
